@@ -11,6 +11,8 @@ y<-2+0.1*trend+mls(x,0:7,4)%*%fn_x+mls(z,0:16,12)%*%fn_z+rnorm(n)
 
 spd <- split_data(list(y = y, x = x, trend = trend, z = z), 1:200, 201:250 )
 
+accuracy <- sqrt(.Machine$double.eps)
+
 ##Add test for preserving zoo and other attributes. 
 ##Add test for printing out the estimation sample start and end.
 
@@ -32,7 +34,7 @@ test_that("midas_r preserves ts attribute",{
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)), data = spd$indata)
     fa <- forecast(a, newdata = spd$outdata)
     expect_true(inherits(fa$mean,"ts"))
-    expect_that(sum(abs(time(fa$mean)-time(ts(201:250,start=c(2006, 9), frequency = 12)))), is_less_than(1e-10))
+    expect_lt(sum(abs(time(fa$mean)-time(ts(201:250,start=c(2006, 9), frequency = 12)))), accuracy)
 })
 
 test_that("midas_u preserves ts attribute",{
@@ -52,7 +54,7 @@ test_that("midas_u preserves ts attribute",{
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)), data = spd$indata)
     fa <- forecast(a, newdata = spd$outdata)
     expect_true(inherits(fa$mean,"ts"))
-    expect_that(sum(abs(time(fa$mean)-time(ts(201:250,start=c(2006, 9), frequency = 12)))), is_less_than(1e-10))
+    expect_lt(sum(abs(time(fa$mean)-time(ts(201:250,start=c(2006, 9), frequency = 12)))), accuracy)
 })
 
 
@@ -61,5 +63,5 @@ test_that("forecast for midas_r and midas_u is the same",{
     b <- midas_u(y~trend+mls(x,0:7,4)+mls(z,0:16,12),start=NULL, data = spd$indata)
     fa <- forecast(a, newdata = spd$outdata)
     fb <- forecast(b, newdata = spd$outdata)
-    expect_that(sum(abs(fa$mean-fb$mean)), is_less_than(1e-10))
+    expect_lt(sum(abs(fa$mean-fb$mean)), accuracy)
 })
\ No newline at end of file
