@@ -9,6 +9,8 @@ fn_x <- nealmon(p = c(1,-0.5),d = 8)
 fn_z <- nealmon(p = c(2,0.5,-0.1),d = 17)
 y <- 2 + 0.1*trend + mls(x, 0:7, 4) %*% fn_x + mls(z, 0:16, 12) %*% fn_z + rnorm(n)
 
+accuracy <- sqrt(.Machine$double.eps)
+
 data_ts <- list(y = ts(as.numeric(y), frequency = 1),
                 x = ts(x, frequency = 4),
                 z = ts(z, frequency = 12),
@@ -22,8 +24,8 @@ test_that("midas_r with start=NULL is the same as lm",{
     
     eq_u3<-midas_u(y~trend+mls(x,0:7,4)+mls(z,0:16,12))
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
-    expect_that(sum(abs(coef(eq_u3) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
+    expect_lt(sum(abs(coef(eq_u3) - coef(eq_u2))), accuracy)
 })
 
 test_that("midas_r with mlsd is the same as mls for start=NULL",{
@@ -33,8 +35,8 @@ test_that("midas_r with mlsd is the same as mls for start=NULL",{
     
     eq_u3 <- midas_u(y~trend+mlsd(x, 0:7, y) + mlsd(z,0:16, y), data = data_ts)
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
-    expect_that(sum(abs(coef(eq_u3) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
+    expect_lt(sum(abs(coef(eq_u3) - coef(eq_u2))), accuracy)
 })
 
 
@@ -43,12 +45,12 @@ test_that("midas_r without weights gives the same summary as midas_u",{
     
     b <-summary(midas_r(y~trend+mls(x,0:7,4)+mls(z,0:16,12),start=NULL), vcov = NULL)
     
-    expect_that(sum(abs(coef(a) - coef(b))), equals(0))
+    expect_lt(sum(abs(coef(a) - coef(b))), accuracy)
     
 })
 
 test_that("midas_r without start throws an error",{
-    expect_that(midas_r(y~trend+mls(x,0:7,4)+mls(z,0:16,12)), throws_error())
+    expect_error(midas_r(y~trend+mls(x,0:7,4)+mls(z,0:16,12)))
     
 })
 
@@ -58,7 +60,7 @@ test_that("midas_u picks up data from main R environment",{
     eq_u2<-midas_u(y~trend+mls(x,0:7,4)+mls(z,0:16,12), 
                    data = list(y = y, trend = trend, x = x, z = z))
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
     
 })
 
@@ -68,7 +70,7 @@ test_that("midas_r picks up data from main R environment",{
     eq_u2<-midas_r(y~trend+mls(x,0:7,4)+mls(z,0:16,12), 
                    data = list(y = y, trend = trend, x = x, z = z), start = NULL)
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
     
 })
 
@@ -82,15 +84,15 @@ test_that("midas_r and midas_u picks data from the parent environment with mlsd"
     
     eq_u3 <- midas_u(yy~trend+mlsd(xx, 0:7, yy) + mlsd(zz,0:16, yy))
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
-    expect_that(sum(abs(coef(eq_u3) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
+    expect_lt(sum(abs(coef(eq_u3) - coef(eq_u2))), accuracy)
 })
 
 
 test_that("NLS problem solution is close to the DGP", {
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
-    expect_that(sum(abs(coef(a) - c(2,0.1,c(1,-0.5),c(2,0.5,-0.1)))), is_less_than(1))
-    expect_that(sum(abs(coef(a,midas=TRUE)-c(2,0.1,fn_x,fn_z))), is_less_than(1))
+    expect_lt(sum(abs(coef(a) - c(2,0.1,c(1,-0.5),c(2,0.5,-0.1)))), 1)
+    expect_lt(sum(abs(coef(a,midas=TRUE)-c(2,0.1,fn_x,fn_z))), 1)
 })
 
 test_that("midas_r gives the same result for mlsd", {
@@ -98,8 +100,8 @@ test_that("midas_r gives the same result for mlsd", {
     
     b <- midas_r(y~trend+mlsd(x,0:7,y,nealmon)+mlsd(z,0:16,y,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)), data = data_ts)
   
-    expect_that(sum(abs(coef(a) - coef(b))), is_less_than(1e-06))
-    expect_that(sum(abs(coef(a,midas=TRUE)-coef(b, midas = TRUE))), is_less_than(1))
+    expect_lt(sum(abs(coef(a) - coef(b))), 1e-08)
+    expect_lt(sum(abs(coef(a,midas=TRUE)-coef(b, midas = TRUE))), accuracy)
 })
 
 
@@ -107,9 +109,9 @@ test_that("midas_r gives the same result for mlsd", {
 test_that("Deriv tests give positive results", {
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
     dt<-deriv_tests(a)
-    expect_that(dt$first, is_false())
-    expect_that(dt$second, is_true())
-    expect_that(sum(abs(dt$gradient))/nrow(a$model), is_less_than(0.002))
+    expect_false(dt$first)
+    expect_true(dt$second)
+    expect_lt(sum(abs(dt$gradient))/nrow(a$model), (0.002))
 })
 
 test_that("Updating Ofunction works", {
@@ -117,16 +119,16 @@ test_that("Updating Ofunction works", {
     b <- update(a, Ofunction = "nls")
     c <- update(b, Ofunction = "optimx", method = c("Nelder-Mead", "BFGS", "spg"))
     
-    expect_that(a$argmap_opt$Ofunction == "optim", is_true())
-    expect_that(b$argmap_opt$Ofunction == "nls", is_true())
-    expect_that(c$argmap_opt$Ofunction == "optimx", is_true())
+    expect_true(a$argmap_opt$Ofunction == "optim")
+    expect_true(b$argmap_opt$Ofunction == "nls")
+    expect_true(c$argmap_opt$Ofunction == "optimx")
     
-    expect_that(inherits(b$opt, "nls"), is_true())
-    expect_that(inherits(c$opt, "optimx"), is_true())
+    expect_true(inherits(b$opt, "nls"))
+    expect_true(inherits(c$opt, "optimx"))
     
-    expect_that(a$convergence == 0, is_true())
-    expect_that(b$convergence == 0, is_true())
-    expect_that(c$convergence == 0, is_true())
+    expect_true(a$convergence == 0) 
+    expect_true(b$convergence == 0) 
+    expect_true(c$convergence == 0) 
     
 })
 
@@ -137,16 +139,16 @@ test_that("Updating Ofunction works for mlsd", {
     b <- update(a, Ofunction = "nls")
     c <- update(b, Ofunction = "optimx", method = c("Nelder-Mead", "BFGS", "spg"))
     
-    expect_that(a$argmap_opt$Ofunction == "optim", is_true())
-    expect_that(b$argmap_opt$Ofunction == "nls", is_true())
-    expect_that(c$argmap_opt$Ofunction == "optimx", is_true())
+    expect_true(a$argmap_opt$Ofunction == "optim")
+    expect_true(b$argmap_opt$Ofunction == "nls")
+    expect_true(c$argmap_opt$Ofunction == "optimx")
     
-    expect_that(inherits(b$opt, "nls"), is_true())
-    expect_that(inherits(c$opt, "optimx"), is_true())
+    expect_true(inherits(b$opt, "nls"))
+    expect_true(inherits(c$opt, "optimx"))
     
-    expect_that(a$convergence == 0, is_true())
-    expect_that(b$convergence == 0, is_true())
-    expect_that(c$convergence == 0, is_true())
+    expect_true(a$convergence == 0)
+    expect_true(b$convergence == 0)
+    expect_true(c$convergence == 0)
     
 })
 
@@ -155,7 +157,7 @@ test_that("Updating Ofunction arguments  works", {
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
     b <- update(a, method = "CG")
     
-    expect_that(b$argmap_opt$method == "CG", is_true())
+    expect_true(b$argmap_opt$method == "CG")
     
 })
 
@@ -166,7 +168,7 @@ test_that("update works with start=NULL",{
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
     eq_u2 <- update(a, start = NULL)
     
-    expect_that(sum(abs(coef(eq_u1) - coef(eq_u2))), equals(0))
+    expect_lt(sum(abs(coef(eq_u1) - coef(eq_u2))), accuracy)
 })
 
 test_that("updating gradient works",{
@@ -174,7 +176,7 @@ test_that("updating gradient works",{
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
     b <- update(a, weight_gradients = list(nealmon = nealmon_gradient))
     
-    expect_that(sum(abs(b$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), equals(0))
+    expect_lt(sum(abs(b$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), accuracy)
 })
 
 test_that("updating data and starting values works",{
@@ -195,7 +197,7 @@ test_that("updating data and starting values works",{
                                                    trend = c$start_opt["trend"]))
     
         
-    expect_that(sum(abs(coef(b) - coef(c))), equals(0))
+    expect_lt(sum(abs(coef(b) - coef(c))), accuracy)
 })
         
 
@@ -206,7 +208,7 @@ test_that("Gradient passing works", {
                      weight_gradients=list(nealmon = nealmon_gradient))
     
     dt <- deriv_tests(eq_r2)
-    expect_that(sum(abs(dt$gradient))/nrow(eq_r2$model), is_less_than(1e-3))
+    expect_lt(sum(abs(dt$gradient))/nrow(eq_r2$model), 1e-3)
     })
 
 test_that("Gradient passing works for default gradients", {
@@ -215,7 +217,7 @@ test_that("Gradient passing works for default gradients", {
                      start = list(x = c(1, -0.5), z = c(2, 0.5, -0.1)),
                      weight_gradients=list())
     
-    expect_that(sum(abs(eq_r2$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), equals(0))
+    expect_lt(sum(abs(eq_r2$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), accuracy)
     
 })
 
@@ -227,7 +229,7 @@ test_that("Gradient passing works with mlsd", {
                      weight_gradients = list(nealmon = nealmon_gradient))
     
     dt <- deriv_tests(eq_r2)
-    expect_that(sum(abs(dt$gradient))/nrow(eq_r2$model), is_less_than(1e-3))
+    expect_lt(sum(abs(dt$gradient))/nrow(eq_r2$model), 1e-3)
 })
 
 test_that("Gradient passing works for default gradients with mlsd", {
@@ -237,7 +239,7 @@ test_that("Gradient passing works for default gradients with mlsd", {
                      data = data_ts,
                      weight_gradients=list())
     
-    expect_that(sum(abs(eq_r2$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), equals(0))
+    expect_lt(sum(abs(eq_r2$term_info$x$gradient(c(1,0.1,0.1)) - nealmon_gradient(c(1,0.1,0.1),8))), accuracy)
     
 })
 
@@ -249,28 +251,28 @@ test_that("Gradient passing works for nls", {
                      weight_gradients=list(nealmon = nealmon_gradient), Ofunction = "nls")
     
     dt <- deriv_tests(eq_r2)
-    expect_that(sum(abs(dt$gradient))/nrow(eq_r2$model), is_less_than(1e-3))
+    expect_lt(sum(abs(dt$gradient))/nrow(eq_r2$model), 1e-3)
 })
 
 
 test_that("Term info gathering works", {
     a <- midas_r(y~trend+mls(x,0:7,4,nealmon)+mls(z,0:16,12,nealmon),start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
-    expect_that(names(coef(a)), is_equivalent_to(c("(Intercept)", "trend", "x1", "x2", "z1", "z2", "z3")))         
-    expect_that(length(coef(a)), equals(7))
-    expect_that(length(coef(a, midas = TRUE)), equals(27))
-    expect_that(names(a$term_info), is_equivalent_to(c("(Intercept)", "trend", "x", "z")))
+    expect_named(coef(a), c("(Intercept)", "trend", "x1", "x2", "z1", "z2", "z3"))         
+    expect_true(length(coef(a)) == 7)
+    expect_true(length(coef(a, midas = TRUE)) == 27)
+    expect_named(a$term_info, c("(Intercept)", "trend", "x", "z"))
     
     lgs <- lapply(a$term_info,"[[","lag_structure")
-    expect_that(lgs[["(Intercept)"]], is_equivalent_to(0))    
-    expect_that(lgs[["trend"]], is_equivalent_to(0))
-    expect_that(lgs[["x"]], is_equivalent_to(0:7))    
-    expect_that(lgs[["z"]], is_equivalent_to(0:16))
+    expect_true(lgs[["(Intercept)"]] == 0)    
+    expect_true(lgs[["trend"]] == 0)
+    expect_identical(lgs[["x"]], 0:7)    
+    expect_identical(lgs[["z"]], 0:16)
     
-    expect_that(a$term_info[["x"]]$weight(coef(a, term_names = "x")), 
-                is_equivalent_to(nealmon(coef(a, term_names = "x"), 8)))
+    expect_identical(a$term_info[["x"]]$weight(coef(a, term_names = "x")), 
+                nealmon(coef(a, term_names = "x"), 8))
     
-    expect_that(a$term_info[["z"]]$weight(coef(a, term_names = "z")), 
-                is_equivalent_to(nealmon(coef(a, term_names = "z"), 17)))
+    expect_identical(a$term_info[["z"]]$weight(coef(a, term_names = "z")), 
+                nealmon(coef(a, term_names = "z"), 17))
     
 })
 
@@ -283,9 +285,9 @@ test_that("AR* model works", {
     cfb <- a$term_info$x$weight(cfx)
     mcfx <- coef(a, midas = TRUE, term_names = "x")
     cfy <- coef(a, midas = TRUE, term_names = "y")
-    expect_that(sum(abs(mcfx[1:4] - cfb[1:4])), equals(0))
-    expect_that(sum(abs(c(cfb[5:8],rep(0,4))-cfb*cfy[1]-mcfx[5:12])), equals(0))
-    expect_that(sum(abs(-cfb*cfy[2]-mcfx[13:20])), equals(0))
+    expect_lt(sum(abs(mcfx[1:4] - cfb[1:4])), accuracy)
+    expect_lt(sum(abs(c(cfb[5:8],rep(0,4))-cfb*cfy[1]-mcfx[5:12])), accuracy)
+    expect_lt(sum(abs(-cfb*cfy[2]-mcfx[13:20])), accuracy)
 })
 
 test_that("AR* model works with gradient", {
@@ -294,7 +296,7 @@ test_that("AR* model works with gradient", {
     b <- midas_r(y ~ trend + mls(y, c(1,4), 1, "*") + mls(x, 0:7, 4, nealmon) 
                  + mls(z, 0:16, 12, nealmon), start=list(x=c(1,-0.5),z=c(2,0.5,-0.1)))
     
-    expect_that(sum(abs(b$gradD(coef(a)) - a$gradD(coef(a)))), is_less_than(1e-9))
+    expect_lt(sum(abs(b$gradD(coef(a)) - a$gradD(coef(a)))), accuracy)
 })
 
 
@@ -306,8 +308,8 @@ test_that("Midas_r_plain works", {
     s <- midas_r_plain(y,cbind(mls(x, 0:7, 4), mls(z, 0:16, 12)), cbind(1, trend), fn_a, 
                             startx = a$start_opt[3:7], startz = a$start_opt[1:2])
     
-    expect_that(sum(abs(coef(s)[c(6:7,1:5)]-coef(a)))
-, is_less_than(1e-11))
+    expect_lt(sum(abs(coef(s)[c(6:7,1:5)]-coef(a)))
+, accuracy)
 })
 
 test_that("Midas_r_plain gradient works", {
@@ -326,12 +328,12 @@ test_that("Midas_r_plain gradient works", {
                         startx = a$start_opt[3:7], startz = a$start_opt[1:2], 
                         grw = gr_fn_a)
     
-    expect_that(sum(abs(coef(s)[c(6:7,1:5)]-coef(a)))
-                , is_less_than(1e-11))
-    expect_that(sum(abs(s$gradient(coef(s))[c(6:7,1:5)]-a$gradient(coef(s)[c(6:7,1:5)]))),
-                is_less_than(1e-10))
-    expect_that(sum(abs(s$gradD(coef(s))[c(26:27,1:25),c(6:7,1:5)]-a$gradD(coef(s)[c(6:7,1:5)]))),
-                equals(0))
+    expect_lt(sum(abs(coef(s)[c(6:7,1:5)]-coef(a)))
+                , (1e-11))
+    expect_lt(sum(abs(s$gradient(coef(s))[c(6:7,1:5)]-a$gradient(coef(s)[c(6:7,1:5)]))),
+                (1e-10))
+    expect_lt(sum(abs(s$gradD(coef(s))[c(26:27,1:25),c(6:7,1:5)]-a$gradD(coef(s)[c(6:7,1:5)]))),
+                accuracy)
     
 })
 
